@@ -27,7 +27,7 @@ def fit_predict_stacked(
                         X_test : pd.DataFrame, 
                         y_test : pd.Series = None, 
                         task : str = 'clsf', 
-                        verbose : int | bool = 0,
+                        verbose : int or bool = 0,
                         early_stopping_rounds : int = 0, 
                         ) -> pd.DataFrame:
     
@@ -160,7 +160,7 @@ def cross_val(  algorithms : list,
                 metric : Callable, 
                 task : str, 
                 cv : int, 
-                verbose : int | bool = 0, 
+                verbose : int or bool = 0, 
                 early_stopping_rounds : int = 0, 
                 ) -> float:
 
