@@ -195,7 +195,7 @@ class Snaplib__222:
                   metric : Callable, 
                   task : str, 
                   cv : int, 
-                  verbose : int | bool = 0, 
+                  verbose : int or bool = 0, 
                   early_stopping_rounds : int = 0, 
                   ) -> float:
 
@@ -245,8 +245,8 @@ class Snaplib__222:
 
     def recover_data(df_in : pd.DataFrame, 
                      device : str = 'cpu',
-                     verbose : int | bool = True,
-                     discrete_columns : list | str = 'auto', 
+                     verbose : int or bool = True,
+                     discrete_columns : list[str] or str = 'auto', 
                      ) -> pd.DataFrame:
         ''' 
         Imputing of missing values (np.nan) in tabular data, not TimeSeries.
